# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: membership.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from etcetra.grpc_api import gogo_pb2 as gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10membership.proto\x12\x0cmembershippb\x1a\ngogo.proto\"7\n\x0eRaftAttributes\x12\x11\n\tpeer_urls\x18\x01 \x03(\t\x12\x12\n\nis_learner\x18\x02 \x01(\x08\"/\n\nAttributes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x63lient_urls\x18\x02 \x03(\t\"\x80\x01\n\x06Member\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x35\n\x0fraft_attributes\x18\x02 \x01(\x0b\x32\x1c.membershippb.RaftAttributes\x12\x33\n\x11member_attributes\x18\x03 \x01(\x0b\x32\x18.membershippb.Attributes\"\'\n\x18\x43lusterVersionSetRequest\x12\x0b\n\x03ver\x18\x01 \x01(\t\"e\n\x1b\x43lusterMemberAttrSetRequest\x12\x11\n\tmember_ID\x18\x01 \x01(\x04\x12\x33\n\x11member_attributes\x18\x02 \x01(\x0b\x32\x18.membershippb.Attributes\"7\n\x17\x44owngradeInfoSetRequest\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0b\n\x03ver\x18\x02 \x01(\tB\x10\xc8\xe2\x1e\x01\xe0\xe2\x1e\x01\xd0\xe2\x1e\x01\xc8\xe1\x1e\x00\x62\x06proto3')



_RAFTATTRIBUTES = DESCRIPTOR.message_types_by_name['RaftAttributes']
_ATTRIBUTES = DESCRIPTOR.message_types_by_name['Attributes']
_MEMBER = DESCRIPTOR.message_types_by_name['Member']
_CLUSTERVERSIONSETREQUEST = DESCRIPTOR.message_types_by_name['ClusterVersionSetRequest']
_CLUSTERMEMBERATTRSETREQUEST = DESCRIPTOR.message_types_by_name['ClusterMemberAttrSetRequest']
_DOWNGRADEINFOSETREQUEST = DESCRIPTOR.message_types_by_name['DowngradeInfoSetRequest']
RaftAttributes = _reflection.GeneratedProtocolMessageType('RaftAttributes', (_message.Message,), {
  'DESCRIPTOR' : _RAFTATTRIBUTES,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.RaftAttributes)
  })
_sym_db.RegisterMessage(RaftAttributes)

Attributes = _reflection.GeneratedProtocolMessageType('Attributes', (_message.Message,), {
  'DESCRIPTOR' : _ATTRIBUTES,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.Attributes)
  })
_sym_db.RegisterMessage(Attributes)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), {
  'DESCRIPTOR' : _MEMBER,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.Member)
  })
_sym_db.RegisterMessage(Member)

ClusterVersionSetRequest = _reflection.GeneratedProtocolMessageType('ClusterVersionSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERVERSIONSETREQUEST,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.ClusterVersionSetRequest)
  })
_sym_db.RegisterMessage(ClusterVersionSetRequest)

ClusterMemberAttrSetRequest = _reflection.GeneratedProtocolMessageType('ClusterMemberAttrSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERMEMBERATTRSETREQUEST,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.ClusterMemberAttrSetRequest)
  })
_sym_db.RegisterMessage(ClusterMemberAttrSetRequest)

DowngradeInfoSetRequest = _reflection.GeneratedProtocolMessageType('DowngradeInfoSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNGRADEINFOSETREQUEST,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.DowngradeInfoSetRequest)
  })
_sym_db.RegisterMessage(DowngradeInfoSetRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\310\342\036\001\340\342\036\001\320\342\036\001\310\341\036\000'
  _RAFTATTRIBUTES._serialized_start=46
  _RAFTATTRIBUTES._serialized_end=101
  _ATTRIBUTES._serialized_start=103
  _ATTRIBUTES._serialized_end=150
  _MEMBER._serialized_start=153
  _MEMBER._serialized_end=281
  _CLUSTERVERSIONSETREQUEST._serialized_start=283
  _CLUSTERVERSIONSETREQUEST._serialized_end=322
  _CLUSTERMEMBERATTRSETREQUEST._serialized_start=324
  _CLUSTERMEMBERATTRSETREQUEST._serialized_end=425
  _DOWNGRADEINFOSETREQUEST._serialized_start=427
  _DOWNGRADEINFOSETREQUEST._serialized_end=482
# @@protoc_insertion_point(module_scope)
