# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: etcdserver.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from etcetra.grpc_api import gogo_pb2 as gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x65tcdserver.proto\x12\x0c\x65tcdserverpb\x1a\ngogo.proto\"\xff\x02\n\x07Request\x12\x10\n\x02ID\x18\x01 \x01(\x04\x42\x04\xc8\xde\x1f\x00\x12\x14\n\x06Method\x18\x02 \x01(\tB\x04\xc8\xde\x1f\x00\x12\x12\n\x04Path\x18\x03 \x01(\tB\x04\xc8\xde\x1f\x00\x12\x11\n\x03Val\x18\x04 \x01(\tB\x04\xc8\xde\x1f\x00\x12\x11\n\x03\x44ir\x18\x05 \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x17\n\tPrevValue\x18\x06 \x01(\tB\x04\xc8\xde\x1f\x00\x12\x17\n\tPrevIndex\x18\x07 \x01(\x04\x42\x04\xc8\xde\x1f\x00\x12\x17\n\tPrevExist\x18\x08 \x01(\x08\x42\x04\xc8\xde\x1f\x01\x12\x18\n\nExpiration\x18\t \x01(\x03\x42\x04\xc8\xde\x1f\x00\x12\x12\n\x04Wait\x18\n \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x13\n\x05Since\x18\x0b \x01(\x04\x42\x04\xc8\xde\x1f\x00\x12\x17\n\tRecursive\x18\x0c \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x14\n\x06Sorted\x18\r \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x14\n\x06Quorum\x18\x0e \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x12\n\x04Time\x18\x0f \x01(\x03\x42\x04\xc8\xde\x1f\x00\x12\x14\n\x06Stream\x18\x10 \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x15\n\x07Refresh\x18\x11 \x01(\x08\x42\x04\xc8\xde\x1f\x01\"9\n\x08Metadata\x12\x14\n\x06NodeID\x18\x01 \x01(\x04\x42\x04\xc8\xde\x1f\x00\x12\x17\n\tClusterID\x18\x02 \x01(\x04\x42\x04\xc8\xde\x1f\x00\x42\x10\xc8\xe2\x1e\x01\xe0\xe2\x1e\x01\xd0\xe2\x1e\x01\xc8\xe1\x1e\x00')



_REQUEST = DESCRIPTOR.message_types_by_name['Request']
_METADATA = DESCRIPTOR.message_types_by_name['Metadata']
Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'etcdserver_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.Request)
  })
_sym_db.RegisterMessage(Request)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'etcdserver_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.Metadata)
  })
_sym_db.RegisterMessage(Metadata)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\310\342\036\001\340\342\036\001\320\342\036\001\310\341\036\000'
  _REQUEST.fields_by_name['ID']._options = None
  _REQUEST.fields_by_name['ID']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Method']._options = None
  _REQUEST.fields_by_name['Method']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Path']._options = None
  _REQUEST.fields_by_name['Path']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Val']._options = None
  _REQUEST.fields_by_name['Val']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Dir']._options = None
  _REQUEST.fields_by_name['Dir']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['PrevValue']._options = None
  _REQUEST.fields_by_name['PrevValue']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['PrevIndex']._options = None
  _REQUEST.fields_by_name['PrevIndex']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['PrevExist']._options = None
  _REQUEST.fields_by_name['PrevExist']._serialized_options = b'\310\336\037\001'
  _REQUEST.fields_by_name['Expiration']._options = None
  _REQUEST.fields_by_name['Expiration']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Wait']._options = None
  _REQUEST.fields_by_name['Wait']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Since']._options = None
  _REQUEST.fields_by_name['Since']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Recursive']._options = None
  _REQUEST.fields_by_name['Recursive']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Sorted']._options = None
  _REQUEST.fields_by_name['Sorted']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Quorum']._options = None
  _REQUEST.fields_by_name['Quorum']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Time']._options = None
  _REQUEST.fields_by_name['Time']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Stream']._options = None
  _REQUEST.fields_by_name['Stream']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Refresh']._options = None
  _REQUEST.fields_by_name['Refresh']._serialized_options = b'\310\336\037\001'
  _METADATA.fields_by_name['NodeID']._options = None
  _METADATA.fields_by_name['NodeID']._serialized_options = b'\310\336\037\000'
  _METADATA.fields_by_name['ClusterID']._options = None
  _METADATA.fields_by_name['ClusterID']._serialized_options = b'\310\336\037\000'
  _REQUEST._serialized_start=47
  _REQUEST._serialized_end=430
  _METADATA._serialized_start=432
  _METADATA._serialized_end=489
# @@protoc_insertion_point(module_scope)
